@@ -46,6 +46,7 @@ class Routes:
         self.throw = throw
         self.response = response
         self.errors = list()
+        self.meta = {}
 
     def views(self):
         return list([i for i in self.__class__.__dict__.values() if hasattr(i, '_route_cache')])
@@ -56,21 +57,26 @@ class Routes:
     def payload(self):
         return json.loads(request.data)
 
-    def bake(self, http, data=None, metadata=None, **kwargs):
-        return http(data, **self.metadata(**kwargs, **dict(metadata=dict(count=len(data or [])))))
+    def marshall(self, http, data=None, metadata=None, **kwargs):
+        return http(data, **self.metadata(**kwargs, **dict(count=len(data or []))))
 
     def metadata(self, **kwargs):
         resp = dict()
         resp['links'] = {}
         resp['links']['self'] = request.url
         resp['links']['_self'] = request.base_url
-        resp['metadata'] = dict(args=dict(request.args))
+        resp['metadata'] = self.meta
+        resp['metadata'].update(dict(args=dict(request.args)))
         resp['errors'] = self.errors
 
         if kwargs:
             resp['metadata'].update(kwargs)
+        self.refresh()
         return resp
 
+    def set_metadata(self, key, value):
+        self.meta[key] = value
+
     def json(self, data, *args, **kwargs):
         resp = tojson(data, *args, **kwargs)
         return resp
@@ -93,10 +99,10 @@ class Routes:
         :rtype: HTTPSuccess
         """
 
-        print(request.args.to_dict(flat=False))
         query = QueryBuffer(self.model).apply().all()
         self.errors.extend(query.errors)
-        return self.bake(HTTPSuccess, self.json(query.data, **query.queryargs.__dict__))
+        self.set_metadata('total', query.prepaged)
+        return self.marshall(HTTPSuccess, self.json(query.data, **query.queryargs.__dict__))
 
     @link(url='/<resource>', methods=['HEAD'])
     @route('/<resource>', methods=['HEAD'])
@@ -106,7 +112,7 @@ class Routes:
 
         if not resp:
             raise HTTPNotFound()
-        return self.bake(HTTPSuccess)
+        return self.marshall(HTTPSuccess)
 
     @link(url='/<resource>', methods=['GET'])
     @route('/<resource>', methods=['GET'])
@@ -136,7 +142,7 @@ class Routes:
 
         if not resp.data:
             raise HTTPNotFound(f'{self.model.__tablename__} not found')
-        return self.bake(HTTPSuccess, self.json(query.data, **query.queryargs.__dict__))
+        return self.marshall(HTTPSuccess, self.json(query.data, **query.queryargs.__dict__))
 
     @link(url='/<resource>/<path:field>', methods=['GET'])
     @route('/<resource>/<path:field>', methods=['GET'])
@@ -163,7 +169,7 @@ class Routes:
             raise HTTPNotFound(f'{self.model.__tablename__} not found')
 
         if field not in self.model.__mapper__.relationships:
-            return self.bake(HTTPSuccess, {field: getattr(instance, field)})
+            return self.marshall(HTTPSuccess, {field: getattr(instance, field)})
 
         session = query.session
         tree = False
@@ -192,14 +198,14 @@ class Routes:
 
             # session.query(related).join(self.model.articles).filter(self.model.id==2).all()
 
-            iquery = QueryBuffer(related).build(iquery, query.queryargs)
+            iquery = QueryBuffer(related).apply(iquery, query.queryargs)
             data = iquery.all()
 
         resp = {
             self.model.__tablename__: self.json(instance, **query.queryargs.__dict__),
             field: self.json(data, **query.queryargs.__dict__)
         }
-        return self.bake(
+        return self.marshall(
             HTTPSuccess,
             resp,
             **{
@@ -218,7 +224,7 @@ class Routes:
             raise HTTPNotProcessable(msg='Invalid request payload.')
         instance = self.dao.create(payload, **kwargs)
         # self.dao.save(HTTPCreated)
-        return self.bake(HTTPSuccess, self.json(instance))
+        return self.marshall(HTTPSuccess, self.json(instance))
 
     @link(url='/<resource>/<field>/', methods=['POST'])
     @route('/<resource>/<field>/', methods=['POST'])
@@ -227,7 +233,7 @@ class Routes:
         child = getattr(self.model.__mapper__.relationships, field).entity.entity(**self.payload())
         getattr(instance, field).append(child)
         self.dao.save(instance)
-        return self.bake(HTTPSuccess, self.json(instance))
+        return self.marshall(HTTPSuccess, self.json(instance))
 
     @link(url='/<resource>', methods=['DELETE'])
     @route('/<resource>', methods=['DELETE'])
@@ -238,7 +244,7 @@ class Routes:
 
         if self.dao:
             self.dao.delete(instance.data)
-        return self.bake(HTTPDeleted)
+        return self.marshall(HTTPDeleted)
 
     @link(url='/<resource>', methods=['PUT'])
     @route('/<resource>', methods=['PUT'])
@@ -247,4 +253,4 @@ class Routes:
         instance = query.data
         payload = self.payload()
         self.dao.update(instance, payload)
-        return self.bake(HTTPUpdated, self.json(instance))
+        return self.marshall(HTTPUpdated, self.json(instance))
