@@ -1,4 +1,5 @@
 from datetime import datetime
+from datetime import date
 
 from flask import Flask
 from flask import Response
@@ -9,6 +10,7 @@ from sqlalchemy.orm.collections import InstrumentedList
 
 from sqlalchemy_blender import serialize
 from sqlalchemy_blender import iserialize
+from sqlalchemy_blender.helpers import serializer
 from handyhttp import HTTPException
 
 
@@ -17,11 +19,11 @@ class ModelEncoder(JSONEncoder):
         if isinstance(data, HTTPException):
             return data.pack()
         if isinstance(data, InstrumentedList):
-            return serialize(data)
-        elif isinstance(data, datetime):
+            return serializer(data)
+        elif isinstance(data, (datetime, date)):
             return data.isoformat()
         else:
-            data = iserialize(data)
+            data = serializer(data)
         return data
 
 
